@@ -78,6 +78,9 @@ meatPC <- function(x, cluster = NULL, order.by = NULL, pairwise = FALSE, kroneck
     if(n != NROW(order.by)) order.by <- order.by[-x$na.action]
   }
 
+  ## catch NAs in cluster/order.by -> need to be addressed in the model object by the user
+  if(anyNA(cluster) || anyNA(order.by)) stop("cannot handle NAs in 'cluster' or 'order.by': either refit the model without the NA observations or impute the NAs")
+
   ## model matrix
   X <- model.matrix(x)
  
